.. _visualization:

===============================
Visualization (`visualization`)
===============================

.. currentmodule:: ctapipe.visualization

Introduction
============

This module provides methods to display various information related to
events and reconstruction, like Cherenkov Camera images, image
parameterizations, etc. The default implementation uses MatPlotLib
to render displays, but in the future more rendering methods may be supported.

The main classes are:

* `CameraDisplay`
* `ArrayDisplay` 


Getting Started
===============

.. plot:: ../examples/plot_hillas_parameters.py
    :include-source:


Reference/API
=============

.. automodapi:: ctapipe.visualization
    :no-inheritance-diagram:





